@@ -5,30 +5,33 @@ use std::sync::{Arc, LazyLock};
 use tokio::sync::Mutex;
 use tower_lsp::lsp_types::{self, Location, MessageType, Position, Range, Url};
 
+use crate::scansubs::TREE_CMAKE_MAP;
+use crate::utils::remove_quotation_and_replace_placeholders;
 /// provide go to definition
 use crate::{
+    CMakeNodeKinds,
     consts::TREESITTER_CMAKE_LANGUAGE,
     languageserver::BUFFERS_CACHE,
     scansubs::TREE_MAP,
     utils::{
-        gen_module_pattern, get_the_packagename, include_is_module, replace_placeholders,
-        treehelper::{get_point_string, ToPoint, ToPosition},
-        DocumentNormalize, LineCommentTmp, CACHE_CMAKE_PACKAGES_WITHKEYS,
+        CACHE_CMAKE_PACKAGES_WITHKEYS, DocumentNormalize, LineCommentTmp, gen_module_pattern,
+        get_the_packagename, include_is_module, replace_placeholders,
+        treehelper::{ToPoint, ToPosition, get_point_string},
     },
-    CMakeNodeKinds,
 };
 mod findpackage;
 mod include;
 mod subdirectory;
 use tree_sitter::Node;
 
-use crate::utils::treehelper::{get_pos_type, PositionType};
+use crate::utils::treehelper::{PositionType, get_pos_type};
 
 /// Storage the information when jump
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct JumpCacheUnit {
     pub location: Location,
     pub document_info: String,
+    pub is_function: bool,
 }
 
 pub type JumpKV = HashMap<String, JumpCacheUnit>;
@@ -36,13 +39,12 @@ pub type JumpKV = HashMap<String, JumpCacheUnit>;
 pub static JUMP_CACHE: LazyLock<Arc<Mutex<JumpKV>>> =
     LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
 
-const JUMP_FILITER_KIND: &[&str] = &["identifier", "unquoted_argument"];
-
 #[derive(Debug, Clone, PartialEq, Eq)]
 struct CacheDataUnit {
     key: String,
     location: Location,
     document_info: String,
+    is_function: bool,
 }
 
 pub async fn update_cache<P: AsRef<Path>>(path: P, context: &str) -> Option<()> {
@@ -64,6 +66,7 @@ pub async fn update_cache<P: AsRef<Path>>(path: P, context: &str) -> Option<()>
         key,
         location,
         document_info,
+        is_function,
     } in result_data
     {
         cache.insert(
@@ -71,20 +74,35 @@ pub async fn update_cache<P: AsRef<Path>>(path: P, context: &str) -> Option<()>
             JumpCacheUnit {
                 location,
                 document_info,
+                is_function,
             },
         );
     }
     None
 }
 
-pub async fn get_cached_defs<P: AsRef<Path>>(path: P, key: &str) -> Option<Location> {
+#[derive(Debug, Clone)]
+pub struct ReferenceInfo {
+    is_function: bool,
+    loc: Location,
+}
+
+pub async fn get_cached_def<P: AsRef<Path>>(path: P, key: &str) -> Option<ReferenceInfo> {
     let mut path = path.as_ref().to_path_buf();
 
     let tree_map = TREE_MAP.lock().await;
 
     let jump_cache = JUMP_CACHE.lock().await;
-    if let Some(JumpCacheUnit { location, .. }) = jump_cache.get(key) {
-        return Some(location.clone());
+    if let Some(JumpCacheUnit {
+        location,
+        is_function,
+        ..
+    }) = jump_cache.get(key)
+    {
+        return Some(ReferenceInfo {
+            loc: location.clone(),
+            is_function: *is_function,
+        });
     }
     drop(jump_cache);
     if let Ok(context) = tokio::fs::read_to_string(&path).await {
@@ -96,15 +114,31 @@ pub async fn get_cached_defs<P: AsRef<Path>>(path: P, key: &str) -> Option<Locat
         drop(buffer_cache);
         update_cache(&path, context.as_str()).await;
         let jump_cache = JUMP_CACHE.lock().await;
-        if let Some(JumpCacheUnit { location, .. }) = jump_cache.get(key) {
-            return Some(location.clone());
+        if let Some(JumpCacheUnit {
+            location,
+            is_function,
+            ..
+        }) = jump_cache.get(key)
+        {
+            return Some(ReferenceInfo {
+                loc: location.clone(),
+                is_function: *is_function,
+            });
         }
     }
 
     while let Some(parent) = tree_map.get(&path) {
         let jump_cache = JUMP_CACHE.lock().await;
-        if let Some(JumpCacheUnit { location, .. }) = jump_cache.get(key) {
-            return Some(location.clone());
+        if let Some(JumpCacheUnit {
+            location,
+            is_function,
+            ..
+        }) = jump_cache.get(key)
+        {
+            return Some(ReferenceInfo {
+                loc: location.clone(),
+                is_function: *is_function,
+            });
         }
         drop(jump_cache);
         if let Ok(context) = tokio::fs::read_to_string(&parent).await {
@@ -116,8 +150,16 @@ pub async fn get_cached_defs<P: AsRef<Path>>(path: P, key: &str) -> Option<Locat
             drop(buffer_cache);
             update_cache(&path, context.as_str()).await;
             let jump_cache = JUMP_CACHE.lock().await;
-            if let Some(JumpCacheUnit { location, .. }) = jump_cache.get(key) {
-                return Some(location.clone());
+            if let Some(JumpCacheUnit {
+                location,
+                is_function,
+                ..
+            }) = jump_cache.get(key)
+            {
+                return Some(ReferenceInfo {
+                    loc: location.clone(),
+                    is_function: *is_function,
+                });
             }
         }
         path.clone_from(parent);
@@ -133,9 +175,10 @@ pub async fn godef<P: AsRef<Path>>(
     originuri: P,
     client: &tower_lsp::Client,
     is_jump: bool,
+    just_var_or_fun: bool,
 ) -> Option<Vec<Location>> {
     let current_point = location.to_point();
-    let locations = godef_inner(current_point, source, originuri, is_jump).await;
+    let locations = godef_inner(current_point, source, originuri, is_jump, just_var_or_fun).await;
     if locations.is_none() {
         client
             .log_message(MessageType::INFO, "Not find any locations")
@@ -149,37 +192,49 @@ async fn godef_inner<P: AsRef<Path>>(
     source: &str,
     originuri: P,
     is_jump: bool,
+    just_var_or_fun: bool,
 ) -> Option<Vec<Location>> {
-    let source = source.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
-    let tree = parse.parse(&source, None)?;
+    let tree = parse.parse(source, None)?;
 
     let tofind = get_point_string(location, tree.root_node(), &source.lines().collect())?;
 
-    let jumptype = get_pos_type(location, tree.root_node(), &source);
+    let jumptype = get_pos_type(location, tree.root_node(), source);
+
+    // NOTE: when just find the var or fun, then we need to skip other position type
+    // Because when value in arguments, then it maybe definition, so we also need to handle this
+    // part
+    if !matches!(
+        jumptype,
+        PositionType::VarOrFun | PositionType::ArgumentOrList | PositionType::FunOrMacroIdentifier
+    ) && just_var_or_fun
+    {
+        return None;
+    }
 
     match jumptype {
-        PositionType::VarOrFun => {
+        PositionType::VarOrFun
+        | PositionType::ArgumentOrList
+        | PositionType::FunOrMacroIdentifier => {
             let mut locations = vec![];
-            if let Some(jump_cache) = get_cached_defs(&originuri, tofind).await {
-                if is_jump {
-                    return Some(vec![jump_cache]);
-                }
-                locations.push(jump_cache);
+            let ReferenceInfo {
+                loc: jump_cache,
+                is_function,
+            } = get_cached_def(&originuri, tofind).await?;
+            if is_jump {
+                return Some(vec![jump_cache]);
             }
 
-            let newsource: Vec<&str> = source.lines().collect();
-            if let Some(mut defdata) =
-                simplegodefsub(tree.root_node(), &newsource, tofind, originuri, is_jump)
-            {
-                locations.append(&mut defdata);
-            }
-            if locations.is_empty() {
-                None
-            } else {
-                Some(locations)
-            }
+            let Ok(loc) = jump_cache.uri.to_file_path() else {
+                return None;
+            };
+            locations.push(jump_cache);
+            let mut defdata = reference_all(&loc, tofind, is_function).await;
+            locations.append(&mut defdata);
+            // NOTE: ensure there is not same location, or it will cause problems
+            locations.dedup();
+            Some(locations)
         }
         PositionType::FindPackageSpace(space) => {
             let newtofind = format!("{space}{}", get_the_packagename(tofind));
@@ -190,11 +245,7 @@ async fn godef_inner<P: AsRef<Path>>(
             findpackage::cmpfindpackage(tofind)
         }
         // NOTE: here is reserve to do next time
-        PositionType::Unknown
-        | PositionType::Comment
-        | PositionType::ArgumentOrList
-        | PositionType::FunOrMacroArgs
-        | PositionType::FunOrMacroIdentifier => None,
+        PositionType::Unknown | PositionType::Comment | PositionType::FunOrMacroArgs => None,
         #[cfg(unix)]
         PositionType::FindPkgConfig => None,
         PositionType::Include => {
@@ -208,32 +259,90 @@ async fn godef_inner<P: AsRef<Path>>(
     }
 }
 
+async fn reference_all<P: AsRef<Path>>(path: P, tofind: &str, is_function: bool) -> Vec<Location> {
+    let mut results = vec![];
+    let from = path.as_ref();
+    let mut paths: Vec<PathBuf> = if from
+        .extension()
+        .is_some_and(|extension| extension == "cmake")
+    {
+        let avaiablepaths = TREE_CMAKE_MAP.lock().await;
+        let mut temp: Vec<PathBuf> = avaiablepaths
+            .iter()
+            .filter(|(cmake, _parents)| **cmake == from)
+            .flat_map(|(_, parents)| parents.clone())
+            .collect();
+
+        let mut results = vec![];
+        let map = TREE_MAP.lock().await;
+        for included in temp.iter() {
+            let mut childrens = map
+                .iter()
+                .filter(|(_child, parent)| *parent == included)
+                .map(|(child, _)| child.clone())
+                .collect();
+            results.append(&mut childrens);
+        }
+        results.append(&mut temp);
+        results
+    } else {
+        let map = TREE_MAP.lock().await;
+        map.iter()
+            .filter(|(_child, parent)| **parent == from)
+            .map(|(child, _)| child.clone())
+            .collect()
+    };
+    paths.push(from.to_path_buf());
+
+    for rp in paths {
+        let Ok(source) = tokio::fs::read_to_string(&rp)
+            .await
+            .map(|source| source.normalize())
+        else {
+            continue;
+        };
+        let mut parse = tree_sitter::Parser::new();
+        parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
+        let Some(tree) = parse.parse(&source, None) else {
+            continue;
+        };
+        let newsource = source.lines().collect();
+        if let Some(mut locs) =
+            reference_inner(tree.root_node(), &newsource, tofind, rp, is_function)
+        {
+            results.append(&mut locs);
+        }
+    }
+    results
+}
+
 /// sub get the def
-fn simplegodefsub<P: AsRef<Path>>(
+fn reference_inner<P: AsRef<Path>>(
     root: Node,
     newsource: &Vec<&str>,
     tofind: &str,
     originuri: P,
-    is_jump: bool,
+    is_function: bool,
 ) -> Option<Vec<Location>> {
     let mut definitions: Vec<Location> = vec![];
     let mut course = root.walk();
     for child in root.children(&mut course) {
-        // if is inside same line
-        //
-        if child.kind() == CMakeNodeKinds::IDENTIFIER {
-            continue;
-        }
         if child.child_count() != 0 {
-            if is_jump && JUMP_FILITER_KIND.contains(&child.kind()) {
-                continue;
-            }
             if let Some(mut context) =
-                simplegodefsub(child, newsource, tofind, originuri.as_ref(), is_jump)
+                reference_inner(child, newsource, tofind, originuri.as_ref(), is_function)
             {
                 definitions.append(&mut context);
             }
-        } else if child.start_position().row == child.end_position().row {
+            continue;
+        }
+        if child.start_position().row == child.end_position().row {
+            // NOTE: if different, means it is not what I want
+            if (child.kind() == CMakeNodeKinds::IDENTIFIER) ^ is_function {
+                continue;
+            }
+            if child.kind() != CMakeNodeKinds::VARIABLE && !is_function {
+                continue;
+            }
             let h = child.start_position().row;
             let x = child.start_position().column;
             let y = child.end_position().column;
@@ -277,8 +386,6 @@ fn getsubdef<P: AsRef<Path>>(
         comments: vec![],
     };
     for child in input.children(&mut course) {
-        let start = child.start_position().to_position();
-        let end = child.end_position().to_position();
         match child.kind() {
             CMakeNodeKinds::LINE_COMMENT => {
                 let start_x = child.start_position().column;
@@ -305,6 +412,8 @@ fn getsubdef<P: AsRef<Path>>(
                 let Some(function_name) = argument_list.child(0) else {
                     continue;
                 };
+                let start = function_name.start_position().to_position();
+                let end = function_name.end_position().to_position();
                 let x = function_name.start_position().column;
                 let y = function_name.end_position().column;
                 let h = function_name.start_position().row;
@@ -323,6 +432,7 @@ fn getsubdef<P: AsRef<Path>>(
                         range: Range { start, end },
                     },
                     document_info,
+                    is_function: true,
                 });
             }
             CMakeNodeKinds::MACRO_DEF => {
@@ -335,6 +445,8 @@ fn getsubdef<P: AsRef<Path>>(
                 let Some(marco_name) = argument_list.child(0) else {
                     continue;
                 };
+                let start = marco_name.start_position().to_position();
+                let end = marco_name.end_position().to_position();
                 let x = marco_name.start_position().column;
                 let y = marco_name.end_position().column;
                 let h = marco_name.start_position().row;
@@ -353,6 +465,7 @@ fn getsubdef<P: AsRef<Path>>(
                         range: Range { start, end },
                     },
                     document_info,
+                    is_function: true,
                 });
             }
             CMakeNodeKinds::IF_CONDITION | CMakeNodeKinds::FOREACH_LOOP | CMakeNodeKinds::BODY => {
@@ -382,13 +495,16 @@ fn getsubdef<P: AsRef<Path>>(
                         let x = ids.start_position().column;
                         let y = ids.end_position().column;
                         let name = &source[h][x..y];
+                        let Some(name) = remove_quotation_and_replace_placeholders(name) else {
+                            continue;
+                        };
                         let (is_builtin, subpath) = {
-                            if !include_is_module(name) {
+                            if !include_is_module(&name) {
                                 (false, local_path.parent().unwrap().join(name))
                             } else {
                                 // NOTE: Module file now is not works on windows
                                 // Maybe also not works on android, please make pr for me
-                                let Some(glob_pattern) = gen_module_pattern(name) else {
+                                let Some(glob_pattern) = gen_module_pattern(&name) else {
                                     continue;
                                 };
                                 let Some(path) = glob::glob(&glob_pattern)
@@ -524,6 +640,7 @@ fn getsubdef<P: AsRef<Path>>(
                             },
                         },
                         document_info,
+                        is_function: false,
                     });
                 }
             }
@@ -545,11 +662,7 @@ fn getsubdef<P: AsRef<Path>>(
             defs.append(&mut message);
         }
     }
-    if defs.is_empty() {
-        None
-    } else {
-        Some(defs)
-    }
+    if defs.is_empty() { None } else { Some(defs) }
 }
 
 fn get_cmake_package_defs(
@@ -602,6 +715,7 @@ mod jump_test {
             &jump_file_src,
             &top_cmake,
             true,
+            false,
         )
         .await
         .unwrap();
@@ -654,6 +768,7 @@ add_subdirectory(abcd_test)
             &jump_file_src,
             &top_cmake,
             true,
+            false,
         )
         .await
         .unwrap();
@@ -679,6 +794,7 @@ add_subdirectory(abcd_test)
             &jump_file_src,
             &top_cmake,
             true,
+            false,
         )
         .await
         .unwrap();
@@ -760,9 +876,10 @@ include(efg_test.cmake)
                         line: 1,
                         character: 8
                     }
-                }
+                },
             },
-            document_info: format!("defined variable\nfrom: {}", include_cmake_path.display())
+            document_info: format!("defined variable\nfrom: {}", include_cmake_path.display()),
+            is_function: false
         }]
     );
     assert_eq!(
