@@ -3,12 +3,13 @@ mod config;
 mod test;
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
+use std::process::exit;
 use std::sync::{Arc, LazyLock, RwLock};
 
 use tokio::sync::Mutex;
 use tower_lsp::jsonrpc::{Error as LspError, Result};
 use tower_lsp::lsp_types::*;
-use tower_lsp::{lsp_types, LanguageServer};
+use tower_lsp::{LanguageServer, lsp_types};
 use tree_sitter::Parser;
 
 use self::config::Config;
@@ -17,13 +18,13 @@ use crate::config::CMAKE_LINT_CONFIG;
 use crate::consts::TREESITTER_CMAKE_LANGUAGE;
 use crate::fileapi::DEFAULT_QUERY;
 use crate::formatting::getformat;
-use crate::gammar::{checkerror, ErrorInformation, LintConfigInfo};
+use crate::gammar::{ErrorInformation, LintConfigInfo, checkerror};
 use crate::semantic_token::LEGEND_TYPE;
 use crate::utils::treehelper::ToPosition;
-use crate::utils::{did_vcpkg_project, treehelper, DocumentNormalize, VCPKG_LIBS, VCPKG_PREFIX};
+use crate::utils::{DocumentNormalize, VCPKG_LIBS, VCPKG_PREFIX, did_vcpkg_project, treehelper};
 use crate::{
-    ast, complete, document_link, fileapi, filewatcher, hover, jump, quick_fix, scansubs,
-    semantic_token, utils, BackendInitInfo,
+    BackendInitInfo, ast, complete, document_link, fileapi, filewatcher, hover, jump, quick_fix,
+    rename, scansubs, semantic_token, utils,
 };
 
 pub static BUFFERS_CACHE: LazyLock<Arc<Mutex<HashMap<lsp_types::Url, String>>>> =
@@ -236,6 +237,7 @@ impl LanguageServer for Backend {
                 version: Some(version),
             }),
             capabilities: ServerCapabilities {
+                rename_provider: Some(OneOf::Left(true)),
                 code_action_provider: Some(CodeActionProviderCapability::Simple(true)),
                 text_document_sync: Some(TextDocumentSyncCapability::Options(
                     TextDocumentSyncOptions {
@@ -421,7 +423,10 @@ impl LanguageServer for Backend {
     }
 
     async fn shutdown(&self) -> Result<()> {
-        Ok(())
+        // NOTE: do nothing
+        // Seems tower_lsp won't do anything when receive this command.
+        // Now it should be proper for me to directly exit(0) here
+        exit(0)
     }
 
     async fn did_change_workspace_folders(&self, _: DidChangeWorkspaceFoldersParams) {
@@ -704,7 +709,34 @@ impl LanguageServer for Backend {
                 return Err(LspError::internal_error());
             }
         };
-        Ok(jump::godef(location, context.as_str(), &file_path, &self.client, false).await)
+        Ok(jump::godef(
+            location,
+            context.as_str(),
+            &file_path,
+            &self.client,
+            false,
+            false,
+        )
+        .await)
+    }
+
+    async fn rename(&self, input: RenameParams) -> Result<Option<WorkspaceEdit>> {
+        let edited = input.new_name;
+        let uri = input.text_document_position.text_document.uri;
+        let location = input.text_document_position.position;
+        let storemap = BUFFERS_CACHE.lock().await;
+        let Some(context) = storemap.get(&uri).cloned() else {
+            return Ok(None);
+        };
+        drop(storemap);
+        let file_path = match uri.to_file_path() {
+            Ok(file_path) => file_path,
+            Err(_) => {
+                tracing::error!("Cannot get file_path from {uri:?}");
+                return Err(LspError::internal_error());
+            }
+        };
+        Ok(rename::rename(&edited, location, file_path, &self.client, &context).await)
     }
 
     async fn goto_definition(
@@ -732,7 +764,7 @@ impl LanguageServer for Backend {
                 return Err(LspError::internal_error());
             }
         };
-        match jump::godef(location, &context, &file_path, &self.client, true).await {
+        match jump::godef(location, &context, &file_path, &self.client, true, false).await {
             Some(range) => Ok(Some(GotoDefinitionResponse::Link({
                 range
                     .iter()
