@@ -23,6 +23,7 @@ mod hover;
 mod jump;
 mod languageserver;
 mod quick_fix;
+mod rename;
 mod scansubs;
 mod search;
 mod semantic_token;
@@ -268,7 +269,7 @@ mod editorconfig_test {
 
     use tempfile::NamedTempFile;
 
-    use super::{editconfig_setting_read, EditConfigSetting};
+    use super::{EditConfigSetting, editconfig_setting_read};
     #[test]
     fn tst_editconfig_tab() {
         let mut temp_file = NamedTempFile::new().unwrap();
