@@ -8,19 +8,26 @@ use tokio::sync::Mutex;
 
 use crate::consts::TREESITTER_CMAKE_LANGUAGE;
 use crate::utils::{
-    remove_quotation, remove_quotation_and_replace_placeholders, DocumentNormalize,
+    DocumentNormalize, remove_quotation, remove_quotation_and_replace_placeholders,
 };
-use crate::{complete, jump, CMakeNodeKinds};
+use crate::{CMakeNodeKinds, complete, jump};
 
 /// NOTE: key is be included path, value is the top CMakeLists
 /// This is used to find who is on the top of the CMakeLists
 pub type TreeKey = HashMap<PathBuf, PathBuf>;
+pub type TreeCMakeKey = HashMap<PathBuf, Vec<PathBuf>>;
 
 // NOTE: here get the struct of the tree
 // Cache the data of the struct
+// Key is the child, value is the parent
 pub static TREE_MAP: LazyLock<Arc<Mutex<TreeKey>>> =
     LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
 
+// NOTE: record who is using the cmake file
+// Key is the cmake file, value is the place using it
+pub static TREE_CMAKE_MAP: LazyLock<Arc<Mutex<TreeCMakeKey>>> =
+    LazyLock::new(|| Arc::new(Mutex::new(HashMap::new())));
+
 pub async fn scan_all<P: AsRef<Path>>(project_root: P, is_first: bool) {
     let root_cmake = project_root.as_ref().join("CMakeLists.txt");
     let mut to_scan: Vec<PathBuf> = vec![root_cmake];
@@ -35,17 +42,28 @@ pub async fn scan_all<P: AsRef<Path>>(project_root: P, is_first: bool) {
 }
 
 pub async fn scan_dir<P: AsRef<Path>>(path: P, is_first: bool) -> Vec<PathBuf> {
-    let bufs = scan_dir_inner(path.as_ref(), is_first).await;
+    let (bufs, cmakebufs) = scan_dir_inner(path.as_ref(), is_first).await;
     let mut tree = TREE_MAP.lock().await;
+    let mut includetree = TREE_CMAKE_MAP.lock().await;
     for subpath in bufs.iter() {
         tree.insert(subpath.to_path_buf(), path.as_ref().into());
     }
+    for cmakepath in cmakebufs {
+        let include_key = includetree.entry(cmakepath).or_default();
+        let toaddpath = path.as_ref().into();
+        if !include_key.contains(&toaddpath) {
+            include_key.push(toaddpath);
+        }
+    }
     bufs
 }
 
-async fn scan_dir_inner<P: AsRef<Path>>(path: P, is_first: bool) -> Vec<PathBuf> {
-    let Ok(source) = std::fs::read_to_string(path.as_ref()).map(|source| source.normalize()) else {
-        return Vec::new();
+async fn scan_dir_inner<P: AsRef<Path>>(path: P, is_first: bool) -> (Vec<PathBuf>, Vec<PathBuf>) {
+    let Ok(source) = tokio::fs::read_to_string(path.as_ref())
+        .await
+        .map(|source| source.normalize())
+    else {
+        return (Vec::new(), Vec::new());
     };
 
     if is_first {
@@ -58,13 +76,19 @@ async fn scan_dir_inner<P: AsRef<Path>>(path: P, is_first: bool) -> Vec<PathBuf>
     let tree = tree.root_node();
     let newsource: Vec<&str> = source.lines().collect();
     if tree.is_error() {
-        return Vec::new();
+        return (Vec::new(), Vec::new());
     }
+
     scan_node(&newsource, tree, path)
 }
 
-fn scan_node<P: AsRef<Path>>(source: &Vec<&str>, tree: tree_sitter::Node, path: P) -> Vec<PathBuf> {
+fn scan_node<P: AsRef<Path>>(
+    source: &Vec<&str>,
+    tree: tree_sitter::Node,
+    path: P,
+) -> (Vec<PathBuf>, Vec<PathBuf>) {
     let mut bufs = Vec::new();
+    let mut cmake_bufs = Vec::new();
     let mut course = tree.walk();
     for node in tree.children(&mut course) {
         match node.kind() {
@@ -92,15 +116,37 @@ fn scan_node<P: AsRef<Path>>(source: &Vec<&str>, tree: tree_sitter::Node, path:
                             .join("CMakeLists.txt");
                         bufs.push(subpath.to_path_buf())
                     }
+                } else if command_name.to_lowercase() == "include" && node.child_count() >= 4 {
+                    let ids = node.child(2).unwrap();
+                    if ids.start_position().row == ids.end_position().row {
+                        let h = ids.start_position().row;
+                        let x = ids.start_position().column;
+                        let y = ids.end_position().column;
+                        let name = &source[h][x..y];
+                        let Some(name) = remove_quotation_and_replace_placeholders(name) else {
+                            continue;
+                        };
+                        if !name.ends_with(".cmake") {
+                            continue;
+                        }
+                        let mut cmake_buf_path = PathBuf::from(name);
+
+                        if !cmake_buf_path.is_absolute() {
+                            cmake_buf_path = path.as_ref().parent().unwrap().join(cmake_buf_path)
+                        }
+                        cmake_bufs.push(cmake_buf_path)
+                    }
                 }
             }
             CMakeNodeKinds::IF_CONDITION | CMakeNodeKinds::FOREACH_LOOP | CMakeNodeKinds::BODY => {
-                bufs.append(&mut scan_node(source, node, path.as_ref()));
+                let (mut childbufs, mut newcmakebufs) = scan_node(source, node, path.as_ref());
+                bufs.append(&mut childbufs);
+                cmake_bufs.append(&mut newcmakebufs);
             }
             _ => {}
         }
     }
-    bufs
+    (bufs, cmake_bufs)
 }
 
 #[derive(Deserialize, Debug, Serialize, Clone, PartialEq, Eq)]
@@ -129,7 +175,7 @@ impl fmt::Display for TreeDir {
 
 // Path Input is xxx/CMakeLists.txt
 pub fn get_treedir(path: &Path) -> Option<TreeDir> {
-    let Ok(content) = std::fs::read_to_string(path) else {
+    let Ok(content) = std::fs::read_to_string(path).map(|source| source.normalize()) else {
         return None;
     };
     let mut top = TreeDir {
