@@ -1,16 +1,15 @@
-use lsp_types::Position;
-use lsp_types::Range;
 use std::collections::HashMap;
 use std::iter::zip;
 use std::process::Command;
 use std::sync::LazyLock;
+
+use lsp_types::{Position, Range};
 /// Some tools for treesitter  to lsp_types
 use tower_lsp::lsp_types;
 use tree_sitter::{Node, Point};
 
-use crate::CMakeNodeKinds;
-
 use super::get_node_content;
+use crate::CMakeNodeKinds;
 
 const BLACK_POS_STRING: [&str; 5] = ["(", ")", "{", "}", "$"];
 
@@ -399,7 +398,7 @@ fn get_pos_type_inner<'a>(
                 | PositionType::Comment
                 | PositionType::ArgumentOrList
                 | PositionType::FunOrMacroArgs => {
-                    return get_pos_type_inner(location, child, source, jumptype)
+                    return get_pos_type_inner(location, child, source, jumptype);
                 }
                 // NOTE: it should be designed to cannot be reach
                 PositionType::FindPackageSpace(_) | PositionType::FunOrMacroIdentifier => {
